@@ -234,7 +234,7 @@ void SecretAgent::dialogAccepted()
 
                     // Load temporary secrets from auth dialog which are not returned to NM
                     for (const QString &key : tmpOpenconnectSecrets.keys()) {
-                        if (secrets.contains(QLatin1Literal("save_passwords")) && secrets.value(QLatin1Literal("save_passwords")) == QLatin1String("yes")) {
+                        if (secrets.contains(QLatin1String("save_passwords")) && secrets.value(QLatin1String("save_passwords")) == QLatin1String("yes")) {
                             data.insert(key + QLatin1String("-flags"), QString::number(NetworkManager::Setting::AgentOwned));
                         } else {
                             data.insert(key + QLatin1String("-flags"), QString::number(NetworkManager::Setting::NotSaved));
